import argparse

from .scrape import PropertyScraper


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--location', '-l', dest='loc', type=str, required=True, help='Name of location e.g. postcode')
    parser.add_argument('--database', '-d', dest='database', help='Name of database endpoint')
    parser.add_argument('--port', '-o', dest='port', default=3306, help='Database port number')
    parser.add_argument('--user', '-u', dest='user', help='Database username')
    parser.add_argument('--password', '-p', dest='password', help='Database password')
    parser.add_argument('--schema', '-s', dest='schema', help='Name of database schema')
    parser.add_argument('--table', '-b', dest='table', help='Name of database table')
    parser.add_argument('--test', '-t', dest='test', action='store_true', help='Get no. of properties for location')
    args = parser.parse_args()

    properties = PropertyScraper(args.loc)

    if args.test:
        _ = properties.search_prices()
    else:
        properties.save_data(database=args.database, port=args.port, user=args.user, password=args.password,
                             schema=args.schema, table=args.table)


if __name__ == '__main__':
    main()



import setuptools


with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name='pyzoopla',
    version='0.1.4',
    author='Imran Khan',
    author_email='imrankhan17@hotmail.co.uk',
    description='A Python package to access information about properties from Zoopla',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/imrankhan17/properties',
    packages=setuptools.find_packages(),
    license='MIT',
    install_requires=[
        'beautifulsoup4',
        'bs4',
        'lxml',
        'numpy',
        'pandas',
        'requests'
    ],
    classifiers=(
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ),
)



import logging
import pymysql
import sys

from pyzoopla.prices import PricesSearch
from pyzoopla.properties import PropertyDetails
from pyzoopla.utils import insert_into_db

logging.basicConfig(level=logging.INFO, format='%(asctime)-15s %(funcName)s:%(lineno)d %(levelname)s - %(msg)s')


class PropertyScraper:

    def __init__(self, location):
        self.location = location

    def search_prices(self):
        search = PricesSearch(location=self.location)

        try:
            _ = search.assumed_search_location
        except AttributeError:
            logging.critical('No location named \'{}\''.format(self.location))
            sys.exit()

        logging.info('Found {:,} properties in location: {}.'.format(search.total_properties,
                                                                     search.assumed_search_location))

        if search.total_properties > 100000:
            logging.warning('A maximum of 100,000 properties can be scraped for this location.')

        return search, search.assumed_search_location, search.total_pages

    def _get_property_ids(self):
        props, location, n_pages = self.search_prices()
        logging.info('About to scrape {} pages of properties for location {}.'.format(n_pages, location))
        return props.all_properties()

    def save_data(self, database=None, port=None, user=None, password=None, schema=None, table=None):
        """Output csv data to disk."""

        db_conn = pymysql.connect(host=database, port=port, user=user, password=password,
                                  cursorclass=pymysql.cursors.DictCursor)
        cur = db_conn.cursor()
        logging.info('Connected to database host: {}'.format(database))

        for prop_id in self._get_property_ids():
            logging.info('Scraping details for property ID: {}'.format(prop_id))
            prop = PropertyDetails(prop_id)
            insert_into_db(db_conn=db_conn, cur=cur, data=prop.all_data(dataframe=False), schema=schema, table=table)

        db_conn.close()
        logging.info('Finished scraping property details')
